@@ -9,7 +9,19 @@ use bytes;
 # reset to normal at the end of each line.
 $Term::ANSIColor::AUTORESET = 1;
 
-our $VERSION = '0.86';
+our $VERSION = '0.87';
+
+####################
+# new
+####################
+sub new {
+    my $proto = shift;
+    my $class = ref($proto) || $proto;
+    my $self  = $class->SUPER::new(@_);
+    $self->{PLACE_HOLDERS_CONATAIN_DOLLARS} = 0;
+    bless ($self, $class); # reconsecrate
+    return $self;
+} # of new
 
 ###################################################################
 # $statement = get($key, { var1 => $value1, var2 => value2 ... })
@@ -31,6 +43,12 @@ sub get {
 	    $ENV{PHRASEBOOK_SQL_SAVE_STATEMENTS_FILE_PATH};
     }
 
+    if ($self->{PLACE_HOLDERS_CONATAIN_DOLLARS}) {
+	foreach my $key (keys(%$variables)) {	
+	    $variables->{$key} =~ s/\$/__DOLLAR__/g;
+	}
+    }
+
     if ($debug_prints) {
 	if ($debug_prints eq "color") {
 	    # check that all the variables defined in $variables
@@ -153,11 +171,15 @@ sub get {
 	$statement =~ s/\= *NULL/is NULL/ig;
     }
 
+    if ($self->{PLACE_HOLDERS_CONATAIN_DOLLARS}) {
+	$statement =~ s/__DOLLAR__/\$/g;
+    }
+
     # remove new lines if needed
     if ($self->{REMOVE_NEW_LINES}) {
 	$statement =~ s/\n//g; 
     }
-
+    
     # debug prints
     if ($debug_prints) {
 	if ($debug_prints eq "color") {
@@ -257,6 +279,16 @@ sub save_statements_file_path {
     return $self->{SAVE_STATEMENTS_FILE_PATH};
 } # of save_statements_file_path
 
+#################################
+# place_holders_conatain_dollars
+#################################
+sub place_holders_conatain_dollars {
+    my $self = shift;
+    if (@_) {
+        $self->{PLACE_HOLDERS_CONATAIN_DOLLARS} = shift;
+    }
+    return $self->{PLACE_HOLDERS_CONATAIN_DOLLARS};
+} # of place_holders_conatain_dollars
 
 #######################################################
 # is_variables_defined_in_this_line($line, $variables)
@@ -468,6 +500,23 @@ is returned also will be appended to that file. This might be useful while
 debugging big projects - it will let the user have a full log of all the 
 statemnets that were generated by the I<get> method.
 
+=item place_holders_conatain_dollars ( [ BOOLEAN ] )
+
+Access method to the PLACE_HOLDERS_CONATAIN_DOLLARS data member. 
+
+If a place holder value contains dollar sign, it will be processed
+wrongly, and the class will try to replace the dollar sign and the 
+text that follows it with the value of a variable in that name.
+
+If this data member is set to 1 (TRUE), dollar signes are replaced 
+by the string '__DOLLAR__', and later those strings are changed back 
+to dollar signes. 
+
+Because of that overhead, and because I believe that usually
+dollar signes are not included in the place holder values, 
+the PLACE_HOLDERS_CONATAIN_DOLLARS data member is 0 (FALSE) by 
+default.
+
 =back
 
 =head1 ENVIRONMENTS
